@@ -4,7 +4,7 @@ import tkinter,SomeToolspbc.math,copy
 class windows:
     def __init__(self,w,h,x=0,y=0):
         self.win = tkinter.Tk()
-        self.win.geometry(pytools.math.add(str(w),'x',str(h),'+',str(x),'+',str(y)))
+        self.win.geometry(SomeToolspbc.math.add(str(w),'x',str(h),'+',str(x),'+',str(y)))
         self.have = {}
     def add(self,obj,name=None):
         if name == None:
